==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Effect/soxr/translations/soxr_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="30"/>
        <source>SoX Resampler Plugin</source>
        <translation>SoX Resampler Plugin</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="51"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Tietoja: SoX Resampler Plugin</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Qmmp SoX Resampler Plugin</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Asetukset Sample Rate Converter Plugin</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Taajuus (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation>Laatu:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Nopea</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Matala</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Keskitaso</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Korkea</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Erittäin korkea</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/Effect/soxr/translations/soxr_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="30"/>
        <source>SoX Resampler Plugin</source>
        <translation>SoX Resampler Plugin</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="50"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Tietoja: SoX Resampler Plugin</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="51"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Qmmp SoX Resampler Plugin</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SoXRSettingsDialog</name>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Asetukset Sample Rate Converter Plugin</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Taajuus (Hz):</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation>Laatu:</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Nopea</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Matala</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Keskitaso</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Korkea</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Erittäin korkea</translation>
    </message>
</context>
</TS>
